import "./Control.css";
import React, { useRef, useContext, useEffect, useCallback, createContext } from 'react';
import cn from '../cn';
export default function LayersControl({
  children,
  frontLayer,
  root = false
}) {
  const {
    frontLayer: parentFrontLayer,
    nesting,
    children: layerSiblings
  } = useContext(Context);
  if (!frontLayer) frontLayer = parentFrontLayer;
  const activeComponent = useRef(() => {});
  const layerChildren = useRef(new Set()).current;
  const setCurrentComponent = useCallback((close = () => {}) => {
    for (const close of layerChildren) close();

    activeComponent.current();
    activeComponent.current = close;
  }, [activeComponent, layerChildren]);
  const closeComponentOnInteract = useCallback(event => {
    if (!preventedCloseEvents.has(event)) setCurrentComponent();
    preventedCloseEvents.add(event);
  }, [setCurrentComponent]);
  useEffect(() => {
    const close = () => activeComponent.current();

    layerSiblings.add(close);
    return () => {
      layerSiblings.delete(close);
    };
  }, [layerSiblings]);
  return /*#__PURE__*/React.createElement(Context.Provider, {
    value: {
      frontLayer,
      setCurrentComponent,
      nesting: nesting + 1,
      children: layerChildren
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: cn('Layers', 'Control')({
      root
    }),
    onClick: closeComponentOnInteract
  }, children));
}
export function useLayersControlContext() {
  const {
    frontLayer,
    setCurrentComponent,
    nesting
  } = useContext(Context);
  if (!frontLayer) throw new Error('Layers Control context is not set');
  return {
    frontLayer,
    setCurrentComponent,
    nesting
  };
}
const Context = /*#__PURE__*/createContext({
  frontLayer: undefined,
  setCurrentComponent: () => {},
  nesting: 0,
  children: new Set()
});
Context.displayName = 'LayersControlContext';
const preventedCloseEvents = new WeakSet();