import "./index.css";
import React, { useState, useRef, useLayoutEffect } from 'react';
import cn from '../cn';
import Container from '../Container';
import Content from './Content';
export default function Popup({
  children,
  active = false,
  calculatePosition,
  renderMode = 'always'
}) {
  const element = useRef(null);
  const wasActiveOnce = useRef(false);
  if (active) wasActiveOnce.current = true;
  const [{
    top,
    right,
    bottom,
    left,
    verticalPosition,
    horizontalPosition
  }, setPosition] = useState({});
  useLayoutEffect(() => {
    if (active && element.current) setPosition(calculatePosition(element.current.getBoundingClientRect()));
  }, [active, calculatePosition]);
  const result = /*#__PURE__*/React.createElement(Container, Object.assign({
    domRef: element,
    className: cn('Popup')(),
    direction: "vertical"
  }, parsePositionType(verticalPosition), {
    startOffset: top,
    endOffset: bottom
  }), props => /*#__PURE__*/React.createElement(Container, Object.assign({
    direction: "horizontal"
  }, parsePositionType(horizontalPosition), {
    startOffset: left,
    endOffset: right
  }, props), props => /*#__PURE__*/React.createElement(Content, props, children)));

  switch (renderMode) {
    case 'always':
      return result;

    case 'whenActive':
      return active ? result : null;

    case 'afterFirstActivate':
      return wasActiveOnce.current ? result : null;
  }
}

function parsePositionType(type) {
  if (!type) return {};
  const strictIndex = type.indexOf('Strict');
  return strictIndex === -1 ? {
    positioning: type
  } : {
    positioning: type.slice(0, strictIndex),
    strictPositioning: true
  };
}